( cd usr/bin ; rm -rf f77 )
( cd usr/bin ; ln -sf gfortran f77 )
( cd usr/bin ; rm -rf f95 )
( cd usr/bin ; ln -sf gfortran f95 )
( cd usr/bin ; rm -rf g77 )
( cd usr/bin ; ln -sf gfortran g77 )
( cd usr/bin ; rm -rf g95 )
( cd usr/bin ; ln -sf gfortran g95 )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-g77 )
( cd usr/bin ; ln -sf gfortran-gcc-4.2.4 x86_64-slamd64-linux-g77 )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-g95 )
( cd usr/bin ; ln -sf gfortran-gcc-4.2.4 x86_64-slamd64-linux-g95 )
( cd usr/bin ; rm -rf fortran )
( cd usr/bin ; ln -sf gfortran-gcc-4.2.4 fortran )
( cd usr/bin ; rm -rf gfortran )
( cd usr/bin ; ln -sf gfortran-gcc-4.2.4 gfortran )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-gfortran )
( cd usr/bin ; ln -sf gfortran-gcc-4.2.4 x86_64-slamd64-linux-gfortran )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-gfortran-4.2.4 )
( cd usr/bin ; ln -sf gfortran-gcc-4.2.4 x86_64-slamd64-linux-gfortran-4.2.4 )
( cd usr/lib64 ; rm -rf libgfortran.so )
( cd usr/lib64 ; ln -sf libgfortran.so.2.0.0 libgfortran.so )
( cd usr/lib64 ; rm -rf libgfortran.so.2 )
( cd usr/lib64 ; ln -sf libgfortran.so.2.0.0 libgfortran.so.2 )
